function [MEV, MEVCurv, maxEVCurvCA] = EVCurvCF(expName, kVals, pointsParams, saveFlag, plotFlag)

% closed form function to calculate grad and curvature of EV curve at MEV solution

nK = length(kVals);

if strcmp(expName, 'E1E2') | strcmp(expName, 'E3')
    arcAngles = 1:1:100; 
elseif strcmp(expName, 'WGMC')
    arcAngles = 1:1:120;
end
nAngles = length(arcAngles);

% get p(catch) using fitted params
load(['pCatchParams', expName])
for i = 1:nK
    probCatch(i, :) = probFunc(fitParams(i, :), 'logistPoly2', arcAngles);
end

%catcher sizes
arcAnglesK = repmat(arcAngles, nK, 1);

% get EV curve (based on MC prob data)
maxCatch = pointsParams(1);
penPerDeg = pointsParams(2);
miss = pointsParams(3); % always 0 (gain case but same curvature for others)
pointsCatch = maxCatch + penPerDeg * arcAngles;
pointsCatchRep = repmat(pointsCatch, nK, 1);

EVPure = probCatch.*pointsCatchRep+(1-probCatch).*miss;
%EVsm = smoothdata(EV, 2, 'gaussian', 5, 'samplepoints', arcAngles)
for i = 1:nK
    %EV(i, :) = EVPure(i, :)/max(EV(nK, :)); % norm WRT max of highest curve
    %EV(i, :) = EVPure(i, :)/maxCatch;
    EV(i, :) = EVPure(i, :);
    maxEV(i) = max(EV(i, :));
    MEV(i) = find(EV(i, :) == maxEV(i));
end

% closed form 1st and 2nd deriv of EV (See paper)
a = fitParams(:, 1); b = fitParams(:, 2);
aThet = repmat(a, 1, nAngles); bThet = repmat(b, 1, nAngles);
% get f = a*thet + b*thet^2 (exponent in logistic fit) and derivs
f = aThet.*arcAnglesK+bThet.*arcAnglesK.^2;
fdash = aThet+2*bThet.*arcAnglesK;
f2dash = 2*bThet;
% get pCatch derivatives based on polynomial logistic functional form in fit
pdash = 2*fdash.*exp(-f)./((1+exp(-f)).^2);
% 2nd deriv requires a bit more work
u = 2*fdash.*exp(-f); v = 1./((1+exp(-f)).^2);
udash = 2*(exp(-f).*f2dash - exp(-f).*fdash.^2);
vdash = 2*fdash.*exp(-f)./((1+exp(-f)).^3);
p2dash = u .* vdash + udash .* v; % chain rule
% get EV derivs in terms of p and its derivs
% unnormalised
EVdash = pdash.*(pointsCatchRep - miss) + probCatch*penPerDeg;
EV2dash = p2dash.*(pointsCatchRep - miss) + 2*pdash*penPerDeg;

% Curvature
EVCurv = EV2dash./((1+EVdash.^2).^(3/2));
%EVCurvNorm = EV2dashNorm./((1+EVdashNorm.^2).^(3/2));

% absolute Curvature
EVCurvAbs = abs(EVCurv);

% max absolute curvature
for i = 1:nK
    EVCurvMax(i) = max(EVCurvAbs(i, :));
    maxEVCurvCA(i) = find(EVCurvAbs(i, :) == EVCurvMax(i));
end


if saveFlag
    save('maxCurvCA_E1.mat', 'maxCurvCA_E1')
    save('maxCurvCA_E2.mat', 'maxCurvCA_E2')
    save('maxCurvCA_E3.mat', 'maxCurvCA_E3')
end


if plotFlag
    figure(1)
        %plot(arcAngles, squeeze(probCatchNoisy), 'o')
        %hold on;
        plot(arcAngles, probCatch)
        ylabel('prob'); xlabel('theta')
    
    figure(2)
    subplot(2, 2, 1)
    plot(arcAngles, EV);
    hold on
    %plot(arcAngles, EVsm);
    for i = 1:nK
        plot(maxEVCurvCA(i), EV(i, maxEVCurvCA(i)), 'r*', 'markersize', 10)
        plot([MEV(i) MEV(i)], [0 maxCatch]);
    end
    hold off;
    ylabel('EV'); xlabel('theta')
    
    subplot(2, 2, 2)
    plot(arcAngles(1:nAngles), EVdash);
    hold on;
    for i = 1:nK
        plot(maxEVCurvCA(i), EVdash(i, maxEVCurvCA(i)), 'r*', 'markersize', 10)
        plot([MEV(i) MEV(i)], [-0.2 0.2]);
    end
    hold off;
    ylabel('EVdash'); xlabel('theta')
    
    subplot(2, 2, 3)
    hold on;
    plot(arcAngles(1:nAngles), EV2dash);
    for i = 1:nK
        plot(maxEVCurvCA(i), EV2dash(i, maxEVCurvCA(i)), 'r*', 'markersize', 10)
        plot([MEV(i) MEV(i)], [0 0.2]);
    end
    hold off;
    ylabel('EVdash2'); xlabel('theta')
    hold off;
    
    subplot(2, 2, 4)
    hold on;
    plot(arcAngles(1:nAngles), EVCurvAbs);
    for i = 1:nK
        plot(maxEVCurvCA(i), EVCurvAbs(i, maxEVCurvCA(i)), 'r*', 'markersize', 10)
        plot([MEV(i) MEV(i)], [0 0.2]);
    end
    hold off;
    ylabel('Abs Curvature'); xlabel('theta')
end

MEVCurv = diag(EVCurv(:, MEV))';
%MEVCurvNorm = diag(EVCurvNorm(:, MEV))';

end

