function [E1Bias, E2Bias, E3Bias] = biasCACF(saveFlag)
% Plot bias (departure from ideal observer) as a function of EV curvature
% cols k(25, 100, 400), rows gain (big loss, loss, gain)
kE3 = [25 50 75 100];
kE1E2 = [25 100 400];
kWGMC = [50 100 200 600];
nGL_E3 = 2;
nGL_E1E2 = 3;
nGL_WGMC = 1;
pointsParamsE2E3 = [150, -1, 0];
pointsParamsE1 = [300, -3, 0];
pointsParamsWGMC = [6, -0.05, 0];


% load data (in form kvals x 1 x catchSizes) for each student
load('../datMats/E1_meanArrayCAComp');
comp_hum_means_CA_E1 = datArrayMeanComp;
load('../datMats/E2_meanArrayCAComp');
comp_hum_means_CA_E2 = datArrayMeanComp;
load('../datMats/E3_meanArrayCAComp');
comp_hum_means_CA_E3 = datArrayMeanComp;


 [MEV_E1, MEVCurv_E1, maxCurvCA_E1] = EVCurvCF('E1E2', kE1E2, pointsParamsE1, 0, 0);
 [MEV_E2, MEVCurv_E2, maxCurvCA_E2] = EVCurvCF('E1E2', kE1E2,  pointsParamsE2E3, 0, 0);
 [MEV_E3, MEVCurv_E3, maxCurvCA_E3] = EVCurvCF('E3', kE3, pointsParamsE2E3, 0, 0);

if saveFlag
    maxCurvCA = maxCurvCA_E1;
    save('maxCurvCA_E1.mat', 'maxCurvCA')
    maxCurvCA = maxCurvCA_E2;
    save('maxCurvCA_E2.mat', 'maxCurvCA')
    maxCurvCA = maxCurvCA_E3;
    save('maxCurvCA_E3.mat', 'maxCurvCA')
end

% MEV angle
maxAngKE1 = repmat(MEV_E1, nGL_E1E2, 1);
maxAngKE2 = repmat(MEV_E2, nGL_E1E2, 1);
maxAngKE3 = repmat(MEV_E3, nGL_E3, 1);

% Bias
E1Bias = (comp_hum_means_CA_E1 - maxAngKE1);
E2Bias = (comp_hum_means_CA_E2 - maxAngKE2);
E3Bias = (comp_hum_means_CA_E3 - maxAngKE3);

% Percent Bias 
E1BiasPerc = 100*(comp_hum_means_CA_E1 - maxAngKE1)./maxAngKE1;
E2BiasPerc = 100*(comp_hum_means_CA_E2 - maxAngKE2)./maxAngKE2;
E3BiasPerc = 100*(comp_hum_means_CA_E3 - maxAngKE3)./maxAngKE3;

% raw Curvature
MEVCurv_E1GL = repmat(MEVCurv_E1, nGL_E1E2, 1);
MEVCurv_E2GL = repmat(MEVCurv_E2, nGL_E1E2, 1);
MEVCurv_E3GL = repmat(MEVCurv_E3, nGL_E3, 1);

%max curvature CA
maxCurvCA_E1GL = repmat(maxCurvCA_E1, nGL_E1E2, 1);
maxCurvCA_E2GL = repmat(maxCurvCA_E2, nGL_E1E2, 1);
maxCurvCA_E3GL = repmat(maxCurvCA_E3, nGL_E3, 1);



mycol = [0.0 0.0 0.0; 0.5 0.5 0.5; 0.7 0.7 0.7; 0.85 0.85 0.85]


figure (1) % curvature vs bias (degrees) for all data
h1=plot(abs(MEVCurv_E1GL), E1Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(1, :));
set(gca, 'fontsize', 18)
hold on;
h2=plot(abs(MEVCurv_E2GL), E2Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(2, :));
h3=plot(abs(MEVCurv_E3GL), E3Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(3, :));
%h4=plot(abs(MEVCurvNorm_WGMCGL), biasWGMC, 'ko', 'markersize', 10, 'markerfacecolor', mycol(4, :));

xlabel('Curvature of EV function at MEV')
ylabel('Bias (degrees)')

% fit poly func to relationship
params = polyfit(abs([MEVCurv_E1GL(:); MEVCurv_E2GL(:); ...
                      MEVCurv_E3GL(:)]), ...
                     [E1Bias(:);       E2Bias(:); ...
                      E3Bias(:)], 2);
ax = axis;
rng = linspace(0, 0.2, 100);
y = polyval(params, rng);
%h4=plot(rng, y, 'k:')  
%legend([h1(1) h2(1) h3(1) h4(1) ], 'Exp1', 'Exp2', 'Exp3', 'Quadratic Fit') 
legend([h1(1) h2(1) h3(1) ], 'Exp1', 'Exp2', 'Exp3') 

hold off;


figure (2) % MEV solution vs bias of MEV angle for all data
h1=plot(maxCurvCA_E1-maxAngKE1, E1Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(1, :));
set(gca, 'fontsize', 18)
hold on;
h2=plot(maxCurvCA_E2-maxAngKE2, E2Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(2, :));
h3=plot(maxCurvCA_E3-maxAngKE3, E3Bias, 'ko', 'markersize', 10, 'markerfacecolor', mycol(3, :));
%h4=plot(maxCurvCA_WGMC, biasWGMC, 'ko', 'markersize', 10, 'markerfacecolor', mycol(4, :));

xlabel('\theta_c(max curvature) - \theta_c(MEV)')
ylabel('Bias (degrees)')

ax = axis;
axSpread = abs(ax(2)-ax(1));
axis([ax(1)-.1*axSpread ax(2)+.1*axSpread ax(3) ax(4)]);
legend([h1(1) h2(1) h3(1) ], 'Exp1', 'Exp2', 'Exp3')   
hold off;


end

