function [datArrayMean, datArraySD] = datCell2Mat(datCell, saveFlag, saveNameMean, saveNameSD)
% convert cell array of data from getDat into more manageable array format 
% datcell form from getDat is: {1 x nP} cell of {nValence x nK} cell of
% [nReps x 1] Arrays. 
% nP is 28 (Iso) or 30 (Isa); nValance = 3; nK = 3; nReps = 24)
%
% Output is nValence x nK x nPs array (averaged over nReps reps)

nPs = size(datCell, 2);
nValence = size(datCell{1}, 1);
nK = size(datCell{1}, 2);
nReps = size(datCell{1}{1, 1});
datArray = zeros(nValence, nK, nPs);

for i =1:nValence
    for j = 1:nK
        for k = 1:nPs
            datArrayMean(i, j, k) = mean(datCell{k}{i, j});
            datArraySD(i, j, k) = std(datCell{k}{i, j});
        end
    end
end

% mean setting over observers
datArrayMeanComp = mean(datArrayMean, 3);
% std of settings over observers
datArraySDComp = std(datArrayMean, 0, 3);

if saveFlag
     save(saveNameMean, 'datArrayMean');
     save(saveNameSD, 'datArraySD');
     save([saveNameMean, 'Comp'], 'datArrayMeanComp');
     save([saveNameSD, 'Comp'], 'datArraySDComp');   
end

end
