function [fitFixPs, fitErrs] = fitFixPCatch(exper, saveFlag)

% function to recover best fitting fixed P(catch) values
% associted with the nValence x nK catcher angle settings

% get pCatch params (loads fitParams which has the p(catch) parameters)
if strcmp(exper, 'E1') | strcmp(exper, 'E2') 
     load ../prob_fit/pCatchParamsE1E2.mat
elseif strcmp(exper, 'E3') 
     load ../prob_fit/pCatchParamsE3.mat
else     
end

% get human data
if strcmp(exper, 'E1') 
    load ../datMats/E1_meanArrayCA.mat
elseif strcmp(exper, 'E2')
    load ../datMats/E2_meanArrayCA.mat
elseif strcmp(exper, 'E3') 
    load ../datMats/E3_meanArrayCA.mat
else     
end % loads a data structure datArrayMean [nValence x nK]

nVal = size(datArrayMean, 1);
nK = size(datArrayMean, 2);
nPs = size(datArrayMean, 3);

options = optimset('display', 'iter');

%%% 1. Fit to each P individually
for i = 1:nPs
    startP = 0.5;
    options = optimset('display', 'iter');
    [fitFixPs(i), fitErrs(i)] = fminsearch('fixPCatchErr', startP, options, fitParams, datArrayMean(:, :, i));
    fitFixPstheta(:, :, i) = repmat(invertPFunc(fitFixPs(i), fitParams)', nVal, 1); 
end

%%% 2. Fit to avg P 
startP = 0.5;
options = optimset('display', 'iter');
[fitFixPavg, fitErrAvg] = fminsearch('fixPCatchErr', startP, options, fitParams, mean(datArrayMean, 3));
fitFixPavgTheta = repmat(invertPFunc(fitFixPavg, fitParams)', nVal, 1); 

if saveFlag
    fNamePs = [exper, '_', 'fitFixPs.mat'];
    fnamePavg = [exper, '_', 'fitFixPavg.mat'];
    fNamePsThet = [exper, '_', 'fitFixPstheta.mat'];
    fNamePsThetAvg = [exper, '_', 'fitFixPavgTheta.mat'];
    fNameErrs = [exper, '_', 'fitFixErrs.mat'];
    fNameErrAvg = [exper, '_', 'fitFixErrAvg.mat'];
    save(fNamePs, 'fitFixPs'); %[1 x nPs] best fitting fixed p(catch) across 9 conds for each P
    save(fNameErrs, 'fitErrs'); %[1 x nPs] errs assocaited with fits
    save(fnamePavg, 'fitFixPavg') %[1x1] best fitting fixed p(catch) across 9 conds for AVERAGE P catcher angles
    save(fNameErrAvg, 'fitErrAvg')%[1x1] err assoc with fit
    save(fNamePsThet, 'fitFixPstheta')%[nVals x nK x nPs] CAs associated with fitted fixed p(catch) for each P 
    save(fNamePsThetAvg, 'fitFixPavgTheta')%[nVals x nK] CAs associted with fitted fixed p(ctch)for avg P 
end
