function theta = invertPFunc(p, pFitParams)

%function to invert the fitted probFunc function
% input
% p = (0,1) probabilities at which to recover the catcher angle
% pFitParams [nK x 2] array of params for fit to p(Catch curve)
% 
% output
% theta = [nK x 1] catcher angles for which p(catch, K) = p


% quadratic parameter (alpha 2 in paper)
a = pFitParams(:,2); 

% linear parameter (alpha 1 in paper)
b = pFitParams(:,1); 

% constant (derive from equation A5)
c = log((1-p)./(1+p)); 

theta = (-b + sqrt(b.^2-4*a.*c))./(2*a);

end

