function [dat, datEarly, datLate] = getDat(exper, var2Get, saveFlag)
% group level wrapper function to get data for all P's and save it in a
% useful format
% exper = 'E1' or 'E2'
% var2Get = column from which to get data from outDat2 data structure
% 11 = dot into occluder pos (ang); 16 = catcher pos (ang); 
% 17 = catcher size (angle); 18 = points
% saveFlag = flag for saving data 
%
% output data will be a 1 x (nPs) cell array
% each cell entry contains data for 1 participant
% Data for each participant organised in a 3 (valence) x 3 (k) cell array
% Each cell entry is a 24 x 1 column array of data value corresponding to
% repetitions for that participant in each (valence, k) condition

if strcmp(exper, 'E1')
    % E1 data
    subj = [1:2, 3, 5:6, 8:30]'; % exclude problem data
    nSubj = length(subj);
    expName = 'E1';
    
elseif strcmp(exper,'E2')
    % E2 data
    subj = [1:30]';
    nSubj = length(subj);
    expName = 'E2';
end

% get the appropriate data from outDat2
for i = 1:nSubj
    fprintf(sprintf('P = %d, %d of %d\n', subj(i), i, nSubj));
    [ outDat, outDat2 ] = stripData2(exper, subj(i));
    [varByCond, varByCondEarly, varByCondMid, varByCondLate] = getVarByCond(outDat2, var2Get);
    dat{i} = varByCond;
    datEarly{i} = varByCondEarly;
    datMid{i} = varByCondMid;
    datLate{i} = varByCondLate;
end

% select relevant columns
if var2Get == 1
    varName = 'trialNo';
    trialNo = dat;
elseif var2Get == 11
    varName = 'dotIntoAng';
    dotIntoAng = dat;
elseif var2Get == 16
    varName = 'catchPosAng';
    catchPosAng = dat;
elseif var2Get == 17
    varName = 'catchAng';
    catchAng = dat;
    catchAngEarly = datEarly;
    catchAngMid = datMid;
    catchAngLate = datLate;
elseif var2Get == 18
    varName = 'points';
    points = dat;
end

if saveFlag
    save(['../datMats/', expName, '_', varName], varName);
    if var2Get == 17
        save(['../datMats/', expName, '_', varName,'Early'], 'catchAngEarly');
        save(['../datMats/', expName, '_', varName,'Mid'], 'catchAngMid');
        save(['../datMats/', expName, '_', varName,'Late'], 'catchAngLate');
    end
end



