function getDatWrapper(saveFlag)
% get load/setup data structures for ME exp using E1 and E2
% data (collected 2019)

% Step 1: Use getDat to read in all data from .txt files - note this is the
% full raw data set i.e. a (1 x nP) cell array of (nVal x nK) cell arrays
% each entry of which is nReps x 1
% Angular position of dot entry to occluder (XXX_dotIntoAng.mat)
getDat('E2', 11, saveFlag);
getDat('E1', 11, saveFlag);
% P set angular position of catcher centre (XXX_catchPosAng.mat)
getDat('E2', 16, saveFlag);
getDat('E1', 16, saveFlag);
% P set angular extent of catcher (XXX_catchAng.mat)
getDat('E2', 17, saveFlag);
getDat('E1', 17, saveFlag);
% Points scored  (XXX_points.mat)
getDat('E2', 18, saveFlag);
getDat('E1', 18, saveFlag);

% Step 2 - convert points and CA cells recovered from getDat to arrays
% Saved outputs: 
%         XXX_meanArrayXXX.mat are nPs x nValence x nK arrays of averages
%         over nReps reps
%         XXX_sdArrayXXX.mat are nPs x nValence x nK arrays of sds
%         over nReps reps
%         XXX_meanArrayXXXComp.mat are nValence x nK arrays of averages
%         over the nPs dimension of XXX_meanArrayXXX.mat (i.e. mean over
%         Ps)
%         XXX_sdArrayXXXComp.mat are nValence x nK arrays of sds
%         over the nPs dimension of XXX_meanArrayXXX.mat  (i.e. sd over 
%         Ps)
% These are needed for calcMaxExp
load('../datMats/E2_points.mat'); E2_points = points; 
load('../datMats/E1_points.mat'); E1_points = points;
load('../datMats/E2_catchAng.mat'); E2_catchAng = catchAng;
load('../datMats/E1_catchAng.mat'); E1_catchAng = catchAng;
datCell2Mat(E2_points, 1, 'E2_meanArrayPoints', 'E2_sdArrayPoints');
datCell2Mat(E1_points, 1, 'E1_meanArrayPoints', 'E1_sdArrayPoints');
datCell2Mat(E2_catchAng, 1, 'E2_meanArrayCA', 'E2_sdArrayCA');
datCell2Mat(E1_catchAng, 1, 'E1_meanArrayCA', 'E1_sdArrayCA');

% Step 3 - get angular catcher pos histograms and do normal fit from XXX_catchPosAng.mat
% Saved Outputs:
%      XXX_relPos_muHat.mat  = nValence x nK array of fitted mu values to
%      distribution of catcher positions
%      XXX_relPos_sigHat.mat) = nValence x nK array of fitted sig values to
%      distribution of catcher positions
% These are needed for calcMaxExp
getPosSD('E2', 1);
getPosSD('E1', 1);
