function [posAngSD, condMeanSD, avgSD, muhat, sighat] = getPosSD(exper, saveFlag)

% function to recover sd (circular) of catcher (angular) position settings 
% relative to the point at which the dot entered the occluder. 
%
% posAngSD = 1 x 28 (nP) cell array of [3 (valence) x 3 (K)] arrays of (circular) sds
%            of position relative to enter point
% condMeanSD = 1 x 28 array of average circular s.d.s over the 9 (valence x
%               K) conditions - ie mean over the 3 x 3 array in each of the 28 entries of
%               posAngSD
% avgSD = average (Circular) SD over all participants and condititoins
%           (i.e. average of values in condMeanSD)
% muhat = 3 (valence) x 3(K) array of mean of gaussian fitted to positions relative to enter points
%  over all participants (nP) and reps (24 per condition)
% sighat = 3 (valence) x 3(K) array of sd of gaussian fitted to positions relative to enter points
%  over all participants (nP) and reps (24 per condition)
 
valence = {'Loss', 'Inter.', 'Gain'};
K = [25 100 400];
nValence = 3;
nK = 3;
nReps = 24;
deg2rad = pi/180;
rad2deg = 180/pi;

if strcmp(exper,'E1')
    load ../datMats/E1_dotIntoAng;
    load ../datMats/E1_catchPosAng;
    nPs = 28;
    expName = 'E1';
elseif strcmp(exper,'E2')
    load ../datMats/E2_dotIntoAng;
    load ../datMats/E2_catchPosAng;
    nPs = 30;
    expName = 'E2';
end
diffs = cell(1, nPs);
posAngSD = cell(1, nPs);
allDiffs = zeros(nValence, nK, nPs*nReps);
for i = 1:nPs
    diffs{i} = cell(nValence, nK);
    circAngSD{i} = zeros(nValence, nK);
    for j = 1:nValence
        for k = 1:nK
            diffs{i}{j, k} = ang180(catchPosAng{i}{j, k} - dotIntoAng{i}{j, k});
            posAngSD{i}(j, k) = rad2deg*circ_std(deg2rad*diffs{i}{j, k});
            allDiffs(j, k, 1+nReps*(i-1):i*nReps) = diffs{i}{j, k};
            subplot(nValence, nK, (j-1)*nK+k)
            
            histogram(allDiffs(j, k, :), 'binwidth', 5)
            set(gca, 'fontsize', 20)
            if j == 3 && k == 1
                xlabel('Relative Angular Position (deg)');
                ylabel('Frequency')
            end
            %title(sprintf('Val = %s, K = %d', valence{j}, K(k)))  
            %axis square
            axis([-125 125 0 225])
        end
    end
    condMeanSD(i) = mean(posAngSD{i}(:));
end

for j = 1:nValence
    for k = 1:nK
        [muhat(j, k),sighat(j, k)] = normfit(squeeze(allDiffs(j, k, :)));
    end
end

avgSD = mean(condMeanSD);

if saveFlag
    save(['../datMats/', expName, '_relPos_muHat'], 'muhat');
    save(['../datMats/', expName, '_relPos_sigHat'], 'sighat');
end

