function [outDat, outDat2] = stripData2(exper, subj)
%load and strip the .txt files from ME gain/mixed/loss experiment
% note returned file is not sorted but reflects order in whic Ps saw trials
% As well as total output data (outDat) this function returns data for
%
% outDat is 9 (nFiles) x 21 (vars) cell of 24x1 arrays (each containing all values for the
% 21 variables) [ nFiles is 9 for all participants 3points x 3sess]
% 9 files correspond in order to:
% (points: -1, sess:1) (points: 0, sess: 1), (points: 1, sess: 1)
% (points: -1, sess:2) (points: 0, sess: 2), (points: 1, sess: 2)
% (points: -1, sess:3) (points: 0, sess: 3), (points: 1, sess: 3)
%
% OutDat2 collapses over the different sessions ie is a 3 x 21 cell array
% containing 72 (3 x 24) entries (1 per trial ovet 3 sessions) 
% each colum corresponds to different variable as in outDat. 
% 3 rows correspond to points = -1, 0, 1.

startDir = pwd;
dataPath = ['../E1E2_ME_gain_loss_data/', exper, '/fine/'];
cd(dataPath)

kVals = [25 100 400];
% nK = length(kVals);
GLVals = [-1 0 1];
nGL = length(GLVals);
kInd = 4;
%setArcInd = 17;
%setAngInd = 16;
%valence = [-1 0 1]; % loss, gain
K = [25 100 400];
nSess = 3;
%nValence = length(valence);
nK = length(K);
nRepsPerFile = 24;
nVars = 18;
pointsInd = 18;
nConds = nK*nGL;

fileStart = 'ME_gainVloss_p';
fNames = dir([fileStart, int2str(subj), '_', '*.txt']);
nFiles = size(fNames, 1);

datNew = [];

outDat = zeros(nVars, nRepsPerFile*nSess*nGL);

%for i = 1:nPs
datBlock = [];
%for j = 1:nValence
%    for k = 1:nSess
for i = 1:nFiles
    %fName = [fileStart, num2str(Participant),...
    %'_sess', num2str(k), '_points',...
    %num2str(valence(j)), '.txt'];
    fid = fopen(fNames(i).name);
    %header = textscan(fid, '%s', 30);
    a = {''};
    while ~strcmp(a{1}, 'Points')
        %strcmp(a, 'Points')
        a = textscan(fid, '%s', 1);
        %a{1}
        %~strcmp(a{1}, 'Points')
    end
    
    dat1 = textscan(fid, '%d %f %f %d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f\r\n');
    datBlock = [datBlock; dat1];
    fclose(fid);
end
outDat = datBlock;

% initialise colums to outdat to flag gain/loss condition, hit flag, previous hit
GLInd = pointsInd +1;
hitInd = pointsInd+2;
prevHitInd = pointsInd+3;
nVars = nVars+3;
for i = 1:nFiles
    outDat{i, GLInd} = zeros(nRepsPerFile, 1); %G or L
    outDat{i, hitInd} = ones(nRepsPerFile, 1); %hit trial
    outDat{i, prevHitInd} = 99*ones(nRepsPerFile, 1); %previous hit
end

% code GL cond, hit, and whenter previous hit
% first work out if in gain or loss block
missedPts = [-300 -150 0; -200 -100 0]; % from E1 and E2 designs
if strcmp(exper,'E1')
    miss = missedPts(1, :);
elseif strcmp(exper, 'E2')
    miss = missedPts(2, :);
end
for i = 1:nFiles
    if subj < 10 
        caseCount = 29;
    else
        caseCount = 30;
    end
        if fNames(i).name(caseCount) == '-'
           gain(i) = -1;
        elseif fNames(i).name(caseCount) == '1'
           gain(i) = 1;
        elseif fNames(i).name(caseCount) == '0'
            gain(i) = 0;
        end

    if gain(i) == -1 
       indMissed = find(outDat{i, pointsInd} == miss(1));
       outDat{i, hitInd}(indMissed) = zeros(length(indMissed), 1);
       outDat{i, GLInd} = -1*ones(nRepsPerFile, 1);
    elseif gain(i) == 0 
       indMissed = find(outDat{i, pointsInd} == miss(2));
       outDat{i, hitInd}(indMissed) = zeros(length(indMissed), 1);
       outDat{i, GLInd} = 0*ones(nRepsPerFile, 1);
    elseif gain(i) == 1 
       indMissed = find(outDat{i, pointsInd} == miss(3));
       outDat{i, hitInd}(indMissed) = zeros(length(indMissed), 1);
       outDat{i, GLInd} = 1*ones(nRepsPerFile, 1);   
    end
    
    % assess previous trials for catch and flag prev catch in new column
    for j = 2:nRepsPerFile
        if outDat{i, hitInd}(j-1) == 1        
            outDat{i, prevHitInd}(j) = 1;
        else
            outDat{i, prevHitInd}(j) = 0;
        end
    end
end


% reorganise outDat to collapse over nSess sessions to generate outDat2
for i = 1:nVars
    for j = 1:nGL
        outDat2{j, i} = [outDat{j, i}; outDat{j+nSess, i}; outDat{j+2*nSess, i}];
    end
end


cd(startDir);

end

