function dat = getDat(exper, var2Get, saveFlag)
% group level wrapper function to get data for all P's and save it in a
% useful format
% exper = 'E1' or 'E2'
% var2Get = column from which to get data from outDat2 data structure
% 11 = dot into occluder pos (ang); 16 = catcher pos (ang); 
% 17 = catcher size (angle); 18 = points
% saveFlag = flag for saving data 
%
% output data will be a 1 x (nPs) cell array
% each cell entry contains data for 1 participant
% Data for each participant organised in a 3 (valence) x 3 (k) cell array
% Each cell entry is a 24 x 1 column array of data value corresponding to
% repetitions for that participant in each (valence, k) condition


%subj = [1:28 30:50]'; % exclude problem data
subj = 1:50;
nSubj = length(subj);
expName = exper;

% get the appropriate data from outDat2
for i = 1:nSubj
    fprintf(sprintf('P = %d, %d of %d\n', subj(i), i, nSubj));
    [ outDat, outDat2 ] = stripE3Data(subj(i));
    varByCond = getVarByCond(outDat2, var2Get);
    dat{i} = varByCond;
end

% select relevant columns
if var2Get == 11
    varName = 'dotIntoAng';
    dotIntoAng = dat;
%elseif var2Get == 16
%    varName = 'catchPosAng';
%    catchPosAng = dat;
elseif var2Get == 17
    varName = 'catchAng';
    catchAng = dat;
elseif var2Get == 18
    varName = 'points';
    points = dat;
end

if saveFlag
    save(['../datMats/', expName, '_', varName], varName);
end



