function [ outDat, outDat2, prevHitDat, prevMissDat, catchByCond2, missByCond2 ] = stripE3Data(subj)
%load and strip the .txt files from E3 gain loss experiment
% note returned file is not sorted but reflects order in whic Ps saw trials
% hit by cond and miss by cond are both 
%
% outDat is nFiles x 21 cell of 32x1 arrays (each containing all values for the
% 21 variables) [ nFiles is 4 for all but 1 participant ]
% prevHitDat & prevMissDat are like outDat but just trials on which last
% trial was a caught/missed (hit + miss sum of number of entries in each cell will be
% 31 - not 32 as no previous trial for first trial)
% catchByCond2 & missByCond2 are  2 (GL conds) x 4 (K conditions) cell arrays each entry is the
% col vec (variable length) of catcher angle values for that condition/file

startDir = pwd;

cd('../E3_ME_gain_loss_data/')


kVals = [25 50 75 100];
% nK = length(kVals);
GLVals = [-1 1];
nGL = length(GLVals);
kInd = 4;
setArcInd = 17;
valence = [-1 1]; % loss, gain
K = [25 50 75 100];
nSess = 2;
nValence = length(valence);
nK = length(K);
nRepsPerFile = 32;
nVars = 18;
pointsInd = 18;
nConds = nK*nValence;

fileStart = 'ME_gainVloss_p';
fNames = dir([fileStart, int2str(subj), '_', '*.txt']);
nFiles = size(fNames, 1);

datNew = [];

outDat = zeros(nVars, nRepsPerFile*nSess*nValence);

%for i = 1:nPs
datBlock = [];
%for j = 1:nValence
%    for k = 1:nSess
if subj == 29
 1;   
end
for i = 1:nFiles
    %fName = [fileStart, num2str(Participant),...
    %'_sess', num2str(k), '_points',...
    %num2str(valence(j)), '.txt'];
    fid = fopen(fNames(i).name);
    header = textscan(fid, '%s', 30);
    dat1 = textscan(fid, '%d %f %f %d %f %f %f %f %f %f %f %f %f %f %f %f %f %f \r\n');
    datBlock = [datBlock; dat1];
    fclose(fid);
end
%dat(:, :, i) = cell2mat(datBlock);

            
outDat = datBlock;
GLInd = pointsInd +1;
hitInd = pointsInd+2;
prevHitInd = pointsInd+3;
% add dummy columns to datblock for gain/loss condition, hit flag, previous hit and gain/loss
for i = 1:nFiles
    outDat{i, GLInd} = zeros(nRepsPerFile, 1); %G or L
    outDat{i, hitInd} = ones(nRepsPerFile, 1); %hit trial
    outDat{i, prevHitInd} = 99*ones(nRepsPerFile, 1); %previous hit
end
 

% code GL cond, hit, and whenter previous hit
% first work out if in gain or loss block
for i = 1:nFiles
    if subj < 10 
        if length(fNames(i).name) == 34
           gain(i) = -1;
        else
           gain(i) = 1;
        end
    else
        if length(fNames(i).name) == 35
           gain(i) = -1;
        else
           gain(i) = 1;
        end
    end
    %if loss look for -100 (missed)
    if gain(i) == -1
       indMissed = find(outDat{i, pointsInd} == -100);
       outDat{i, hitInd}(indMissed) = zeros(length(indMissed), 1);
       outDat{i, GLInd} = -1*ones(nRepsPerFile, 1);
    else % otherwise look for 0 (missed)
       indMissed = find(outDat{i, pointsInd} == 0);
       outDat{i, hitInd}(indMissed) = zeros(length(indMissed), 1);
       outDat{i, GLInd} = 1*ones(nRepsPerFile, 1);
    end
    
    % assess previous trials for catch and flag prev catch in new column
    for j = 2:nRepsPerFile
        if outDat{i, hitInd}(j-1) == 1        
            outDat{i, prevHitInd}(j) = 1;
        else
            outDat{i, prevHitInd}(j) = 0;
        end
    end
end

% split data into trials on which previous trial caught vs missed (using
% 20th column
%nCols = size(outDat, 2);
for k = 1:nFiles
    prevHits = find(outDat{k, prevHitInd} == 1);
    prevMisses = find(outDat{k, prevHitInd} == 0);
    for l = 1:prevHitInd
        prevHitDat{k, l} = outDat{k, l}(prevHits);
        prevMissDat{k, l} = outDat{k, l}(prevMisses);
    end
end

% rearrange CA column by conditions

catchByCond = cell(nFiles, nK);
missByCond = cell(nFiles, nK);
catchByCond2 = cell(nGL, nK);
missByCond2 = cell(nGL, nK);
% rearrange data into condition columns
for m = 1:nFiles
    for l = 1:nK
            indCatch = find(prevHitDat{m, kInd} == kVals(l));
            indMiss = find(prevMissDat{m, kInd} == kVals(l));       
            catchByCond{m, l} = prevHitDat{m, setArcInd}(indCatch);
            missByCond{m, l} = prevMissDat{m, setArcInd}(indMiss);
            if outDat{m, GLInd} == -1
                catchByCond2{1, l} = [catchByCond2{1, l}; catchByCond{m, l}];
                missByCond2{1, l} = [missByCond2{1, l}; missByCond{m, l}];
            else
                catchByCond2{2, l} = [catchByCond2{2, l}; catchByCond{m, l}];
                missByCond2{2, l} = [missByCond2{2, l}; missByCond{m, l}];
            end
            
        % note counts per row should add to 31 (since 1st trial cant be coutned)  in hits + misses 
    end
end
a = [];
% % put gain and loss files together
% for m = 1:nFiles
%     if outDat{m, GLInd} == -1
%         catflag(m) = 1
%         a = [a; catchByCond{m, :}]
%     else
%         flag(m) = 2;
%     end
% end
    

% reorganise outDat to collapse over nSess sessions to generate outDat2
% note 1 missing data (Valence = -1, sess 2) file for P29
if subj ~= 29
    for i = 1:nVars
        for j = 1:nGL
            outDat2{j, i} = [outDat{j, i}; outDat{j+nSess, i}];
        end
    end
end
if subj == 29
    for i = 1:nVars
        outDat2{1, i} = [outDat{1, i}]; % -1 data(1 session)
          outDat2{2, i} =  [outDat{2, i}; outDat{3, i}]; %+1 data (2 sessions)
    end
end



cd(startDir);

end

