function [maxExp, maxAng, comp_hum_means_CA, indivEff ] = calcMaxExp12(exper, pFit, saveFlag)

% exper = student name 'E1' or 'E2'
% pFit = 1 means use logistic fit to MC p(catch) data 0 means just use the
% data (using the fit means can calc derivatives etc in closed form)
% maxExp = optimal EV for (bounded) ideal observer 'optimal' model
% maxAng = optimal capture angles for (bounded) ideal observer 'optimal' model
% comp_hum_means_CA = human cstcher angle settings

if strcmp(exper, 'E1')
    expName = 'E1';
    n_obs = 28;
    maxPointsGain = 300; 
    maxPointsMid  = 150; 
    maxPointsLoss = 0;
    missGain = 0;
    missMid = -150;
    missLoss = -300;
    penPerDegree = -3;
    load ../fix_prob_analyses/E1_fitFixPstheta.mat; % loads fitFixPstheta (best fit fixed p model)
    load ../EV_curvature/maxCurvCA_E1.mat  % loads maxCrv (maximum curvature od EV curve model)
elseif strcmp(exper, 'E2')
    expName = 'E2';
    n_obs = 30;
    maxPointsGain = 150; 
    maxPointsMid  = 50; 
    maxPointsLoss = -50;
    missGain = 0;
    missMid = -100;
    missLoss = -200;
    penPerDegree = -1;
    load ../fix_prob_analyses/E2_fitFixPstheta.mat; % loads fitFixPstheta (best fit fixed p model)
    load ../EV_curvature/maxCurvCA_E2.mat % loads maxCrv (maximum curvature od EV curve model)
end

K = [25 100 400];
nK = length(K);
nValence = 3;
Valence = {'BigLoss'; 'Loss'; 'Gain'}; 
occ_width = [0.025];
arcAngles = 1:1:100;
nCA = length(arcAngles); 
smoothWin = 7;

n_reps = 24; % There were 24 reps for each condition (each valence x K) 

% load simulated probability of catch data
% this  assumes location centred on line from centre to occluder entry point
% with some position noise based on WGCM2012 (See getPosSD for evidence
% this is a reasonable assumption

%this one uses the values for  participant specified
%load([expName, '_probCatchHumNoiseFR60_100_1000']);

%%%%%  P(CATCH)
if pFit == 0
    % this one uses same position sd for all conditions (calculated over all
    % pos setting data to date for 2.5cm occluder width SM, E2, E1)
    load('../prob_catch/E1E2_probCatchHumNoise_newSD_FR60_consistent.mat')
    % Smooth probCatch data to get reduce random noise from MC process
    probCatchNoisy = probCatch;
    probCatch = smoothdata(probCatchNoisy, 3, 'gaussian', smoothWin, 'samplepoints', arcAngles);
    % remove singleton dimension previousy used for occluder width
    probCatch = squeeze(probCatch);
elseif pFit
    
     % just for plotting
    load('../prob_catch/E1E2_probCatchHumNoise_newSD_FR60_consistent.mat')
    probCatchNoisy = probCatch; % just for plotting
     % just for plotting
  
     %use p(catch) fit
     load ../prob_fit/pCatchParamsE1E2
    for i = 1:nK
        probCatch(i, :) = probFunc(fitParams(i, :), 'logistPoly2', arcAngles);
    end
end


% load human performance data 
% capture angle (CA) - comp = composite (i.e. group level)
load(['../datMats/', expName, '_meanArrayCAComp']); % nValence x nK (mean over observers and reps)
load(['../datMats/', expName, '_meanArrayCA']); % nValence x nK x n_obs (mean over reps)
load(['../datMats/', expName, '_sdArrayCAComp']); % nValence x nK (sd's over observers of mean over reps)
load(['../datMats/', expName, '_sdArrayCA']); % nValence x nK x n_obs (sd's over reps) 
hum_means_CA = datArrayMean;
comp_hum_means_CA = datArrayMeanComp;
hum_sds_CA = datArraySD;
comp_hum_sds_CA = datArraySDComp;

% 95% CIs on CAs
ci95_CA = tinv(0.975, 2*n_reps-1)*hum_sds_CA/sqrt(n_reps); 
comp_ci95_CA = tinv(0.975, n_obs-1)*hum_sds_CA/sqrt(n_obs);

load(['../datMats/', expName, '_meanArrayPointsComp']); % nValence x nK (mean over observers and reps)
load(['../datMats/', expName, '_meanArrayPoints']); % nValence x nK x n_obs (mean over reps)
load(['../datMats/', expName, '_sdArrayPointsComp']); % nValence x nK (sd's over observers of mean over reps)
load(['../datMats/', expName, '_sdArrayPoints']); % nValence x nK x n_obs (sd's over reps) 
hum_means_points = datArrayMean;
comp_hum_means_points = datArrayMeanComp;
hum_sds_points = datArraySD;
comp_hum_sds_points = datArraySDComp;

% 95% CIs on Points
ci95_points = tinv(0.975, 2*n_reps-1)*hum_sds_points/sqrt(n_reps); 
comp_ci95_points = tinv(0.975, n_obs-1)*comp_hum_sds_points/sqrt(n_obs);

%calulcate reward as a function of arc length
RGain = maxPointsGain + penPerDegree * (arcAngles);
RMid = maxPointsMid + penPerDegree * (arcAngles);
RLoss = maxPointsLoss + penPerDegree * (arcAngles);
catchPts = [RLoss; RMid; RGain];
missPts = [missLoss*ones(1, nCA); missMid*ones(1, nCA); missGain*ones(1, nCA)];

% calculate expected points: 3 (nValence) x 100 (angles) x 3 (K)
for i = 1:nK
    probCatchRep = repmat(probCatch(i, :), nValence, 1);
    expPoints(:, :, i) = catchPts.*probCatchRep+missPts.*(1-probCatchRep);
end

% get max exp points and assoc arc length
for i = 1:nK         
% note max ind is same for loss, mid and gain so only have to do for one... 
    indMax1 = find(expPoints(1, :, i) == max(expPoints(1, :, i)));
    indMax(i) = indMax1(1); 
    maxExp(:, i) = expPoints(:, indMax(i), i);
    maxAng(i) = arcAngles(indMax(i));
end
if saveFlag
    maxAngName = [expName, '_MEVCA'];
    save([maxAngName, '.mat'], 'maxAng');
end

% calculate efficiency for each observer and composite
% Note: to do this we work out the difference between the human points and
% maxExp points and then express this as a proportion of the maxexp in the 
% gain case (varying with K). This gets around the issue of negative gains
maxExpRep = repmat(maxExp, [1 1 n_obs]);

if strcmp(expName, 'E1') 
    %maxExpRep = repmat(maxExp, [1 1 n_obs]);
    indivEff(3, :, :) = 100*hum_means_points(3, :, :)./maxExpRep(3, :, :);
    indivEff(2, :, :) = 100*(150+hum_means_points(2, :, :))./(150+maxExpRep(2, :, :));
    indivEff(1, :, :) = 100*(300+hum_means_points(1, :, :))./(300+maxExpRep(1, :, :));
end
if strcmp(expName, 'E2') 
    %maxExpRep = repmat(maxExp, [1 1 n_obs]);
    indivEff(3, :, :) = 100*hum_means_points(3, :, :)./maxExpRep(3, :, :);
    indivEff(2, :, :) = 100*(100+hum_means_points(2, :, :))./(100+maxExpRep(2, :, :));
    indivEff(1, :, :) = 100*(200+hum_means_points(1, :, :))./(200+maxExpRep(1, :, :));
end
if saveFlag
    effMatName = [expName, '_indivEff'];
    save([effMatName, '.mat'], 'indivEff');
end

%indivEff(2, :, :) = 100*hum_means_points(2, :, :)./maxExpRep(2, :, :);
%indivEff(1, :, :) = 100*(100+hum_means_points(1, :, :))./(100+maxExpRep(1, :, :));
compEff = mean(indivEff, 3);
compEffsd = std(indivEff, 0, 3);
compEffse = compEffsd/sqrt(n_obs);
compEffCI95 = tinv(0.975, n_obs-1)*compEffse;
eff = cat(3, indivEff, compEff);



%%%%% FIGURES %%%%%%


%mycol = ['b'; 'k'; 'r']
mycol = [.8 .8 .8; .3 .3 .3; 0 0 0];
figure(1)
set(gca, 'fontsize', 20);
hold on;
for i = 1:nK
    %plot(arcAngles, squeeze(probCatchNoisy(i, :, :)), [mycol(i), 'o']);
    plot(arcAngles, squeeze(probCatchNoisy(i, :, :)), 'o',...
         'MarkerEdgeColor', mycol(i, :));
    h(i)=plot(arcAngles, squeeze(probCatch(i, :, :)), 'color', mycol(i, :), 'linewidth', 2);
end
hold off;
axis square;
xlabel('\theta_c - Catcher Angle (deg)')
ylabel('p_c_a_t_c_h(\theta_c, \kappa)');
legend(h, '\kappa = 25', '\kappa = 100', '\kappa = 400');


figure(2)
%plot the catch and miss points schedules for each valence condition
for i = 1:nValence
    subplot(nValence, 1, nValence-(i-1))
    set(gca, 'fontsize', 18);
    hold on;
%     h2(1)=plot(arcAngles, catchPts(i, :), 'k--', 'linewidth', 2);
%     h2(2)=plot(arcAngles, missPts(i, :), 'k:', 'linewidth', 2);
    axis([0 100 missPts(i, 1) catchPts(i, 1)])
    axis square
     for j = 1:nK
         %h(i)=plot(arcAngles, squeeze(expPointsGain(i, :, :)), 'color', mycol(i, :), 'linewidth', 2);
         %   plot([arcAngles(indMax(i)); arcAngles(indMax(i))],...
         %       [-100, 150], 'color', mycol(i, :), 'linewidth', 2)
          h2(j)=plot(arcAngles, expPoints(i, :, j), 'color', mycol(j, :), 'linewidth', 2);
          plot([arcAngles(indMax(j)); arcAngles(indMax(j))],...
                     [-300, 300], 'color', mycol(j, :), 'linewidth', 2)
     end
end
subplot(nValence, 1, nValence)
hold off;
xlabel('\theta_c - Catcher Angle (deg)')
ylabel('Expected Value (points)');
legend(h2, '\kappa = 25', '\kappa = 100', '\kappa = 400')

lower = [-300 -150 0]; upper = [0 150 300];
%mycol = {'r'; 'm'; 'g'}
mycol = [.8 .8 .8; .3 .3 .3; 0 0 0];
figure(3)
for i = 1:nValence       
    for j = 1:nK
         %subplot(nValence, nK, (i-1)*nK + j);
         subplot(nValence, nK, (j-1)*nValence + i);
         set(gca, 'fontsize', 18)
         %title(sprintf('Valence = %s; K = %d', Valence{i}, K(j)));
         hold on;
         plot(arcAngles, expPoints(i, :, j), 'color', mycol(i, :), 'linestyle', '-', 'linewidth', 2);         
         plot(squeeze(hum_means_CA(i, j, :)), squeeze(hum_means_points(i, j, :)), 'ko', 'markerfacecolor', 'k')
         plot([arcAngles(indMax(j)), arcAngles(indMax(j))],...
               [-350, 350], 'color', mycol(i, :), 'linestyle', '-', 'linewidth', 2)
         plot([comp_hum_means_CA(i, j), comp_hum_means_CA(i, j)],...
               [-350, 350], 'k', 'linewidth', 2, 'linestyle', ':') 

         plot(comp_hum_means_CA(i, j), comp_hum_means_points(i, j), 'ko', 'markerfacecolor', 'y', 'markersize', 12);
         axis([0 100 lower(i) upper(i)]) 
    end
end
subplot(3, 3, 7)
ylabel('Points')
xlabel('\theta_c - Catcher Angle (deg)')






%mycol = ['ro';'gs';'bv'; 'y^']
mycol = [0.8 0.8 0.8; .5 .5 .5; 0.2 0.2 0.2];
figure(4)
fitFixPsthet_mean = mean(fitFixPstheta, 3); % mean over obs [nVals x nK]
humSECA = comp_hum_sds_CA/sqrt(n_obs);
set(gca, 'fontsize', 20)
hold on;
%MEV model
plot(K, maxAng, 'r','linewidth', 2)
hand(1)= plot(K, maxAng, 'k^','markersize', 12, 'markerfacecolor', 'r');
%fixP model
plot(K, fitFixPsthet_mean(1, :), 'm','linewidth', 2)
hand(2) = plot(K, fitFixPsthet_mean(1, :), 'k<', 'markersize', 12, 'markerfacecolor', 'm');
%maxCrv model
plot(K, maxCurvCA, 'c','linewidth', 2)
hand(3) = plot(K, maxCurvCA, 'k>', 'markersize', 12, 'markerfacecolor', 'c');
%plot(K, maxAng(:, i), mycol(i, 1))
for i = 1:nValence
    hand(i+3)=plot(K, comp_hum_means_CA(i, :),  'ko', 'markersize', 12, 'markerfacecolor', mycol(i, :));
    errorbar(K, comp_hum_means_CA(i, :),  humSECA(i, :), 'color', mycol(i, :), 'linewidth', 1, 'linestyle', ':');
    %hand((i-1)*nValence+2) = plot(K, comp_hum_means_CA(i, :),  [mycol(i), 'o'], 'markersize', 12, 'markerfacecolor', mycol(i));
    %errorbar(K, comp_hum_means_CA(i, :),  humSECA(i, :), mycol(i), 'linestyle', '-', 'linewidth', 2);
end
legend(hand, 'MEV', 'FixP', 'maxCrv', 'Loss', 'Inter.', 'Gain')
xlabel('Reliability (K)')
ylabel('\theta_c - Catcher Angle (deg)')
hold off;
axis([0 425 20 55])
set(gca, 'xtick', [25 100 400])

% mycol = ['r'; 'm'; 'g'];
% figure(5)
% humSEpoints = comp_hum_sds_points/sqrt(n_obs);
% set(gca, 'fontsize', 16)
% hold on;
% %h1 = plot(K, maxAng, 'b')
% %plot(K, maxAng(:, i), mycol(i, 1))
% for i = 1:nValence
%     plot(K, comp_hum_means_points(i, :),  mycol(i), 'markersize', 10, 'markerfacecolor', 'r');
%     errorbar(K, comp_hum_means_points(i, :),  humSEpoints(i, :), mycol(i), 'linestyle', 'none');
% end
% %legend([h1 h2 h4], 'Optimal', 'Loss', 'Gain')
% xlabel('K')
% ylabel('Points')
% hold off;
% %axis([0 120 30 60])
         
figure(6)
for i = 1:nValence
    for j = 1:nK
        subplot(nValence, nK, (i-1)*nK+j);
        hold on;
        set(gca, 'fontsize', 32)
        bar(squeeze(eff(i, j, 1:n_obs)), 'r');
        bar(n_obs+1, squeeze(eff(i, j, n_obs+1)), 'm');
        set(gca, 'xtick', [], 'ytick', [0 100]);
        %title(sprintf('K = %.0f, W = %.3f', K(i), occ_width));
        errorbar(n_obs+1, eff(i, j, n_obs+1), compEffCI95(i, j), 'k') 
        axis([0 n_obs+2 0 150])
        plot([0 n_obs+5], [100 100], 'k--')
        hold off
    end
end
% subplot(4, 1, 4)
% xlabel('Participant')
% ylabel('Efficiency (%)')
hold off


figure(7)
set(gca, 'fontsize', 24)
hold on;
mycol = [0.7 0.7 0.7; 0.5 0.5 0.5; 0.3 0.3 .3];
errbars=[compEffCI95(1, 1:nK); compEffCI95(2, 1:nK)];
effs = [squeeze(eff(1, 1:nK, n_obs+1)); squeeze(eff(2, 1:nK, n_obs+1))];
h = bar(effs,'grouped');hold on;
ngroups = 2; % gain/loss
nbars = nK;
% Calculating the width for each bar group
groupwidth = min(0.8, nbars/(nbars + 1.5));
for i = 1:nbars
    set(h(i), 'facecolor', mycol(i, :));
    x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
    errorbar(x, effs(:,i), errbars(:,i), 'linestyle', 'none', 'color', [0 0 0]);
end
plot([.5 2.5], [100 100], 'r:')
hold off
ylabel('Efficiency (%)')
set(gca, 'fontsize', 24, 'xtick', [1 2], 'xticklabel', ['Loss'; 'Gain'])
legend('\kappa = 25', '\kappa = 100', '\kappa =400')



