function [maxExp, maxAng, comp_hum_means_CA, indivEff ] = calcMaxExp3(pFit, saveFlag)

K = [25 50 75 100];
nK = length(K);
nVal = 2; % loss and gain
occ_width = [0.025];
arcAngles = 1:1:100;
NtoOcc = 100;
NunderOcc = 1000;
n_reps = 16; % reps for each condition (6 for lo speed and 6 for hi speed)
%nObs = 50; 
nObs = 50;
smoothWin = 7;
expName = 'E3';

%%%%% P(Catch)
if pFit ==0
    % load simulated probability of catch data
    % this assumes location centred on line from centre to occluder entry point
    % with some position noise based on WGCM2012
    % this one uses same position sd for all conditions (calculated over all
    % pos setting data to date for 2.5cm occluder width WGCM2012, Isaac, Isobel)
    load ../prob_catch/E3_probCatchHumNoise_newSD_FR60_consistent; 

    % Smooth probCatch data to get reduce random noise from MC process
    probCatchNoisy = probCatch;
    probCatch = smoothdata(probCatchNoisy, 3, 'gaussian', smoothWin, 'samplepoints', arcAngles);
    
elseif pFit
    % just for plotting
    load ../prob_catch/E3_probCatchHumNoise_newSD_FR60_consistent; 
    probCatchNoisy = probCatch;
    % just for plotting
    
    %use p(catch) fit
    load ../prob_fit/pCatchParamsE3
    for i = 1:nK
        probCatch(i, 1, :) = probFunc(fitParams(i, :), 'logistPoly2', arcAngles)
    end
end


% load human performance data 
% capture angle (CA) - comp = composite (i.e. group level)
load(['../datMats/', expName, '_meanArrayCAComp']); % nValence x nK (mean over observers and reps)
load(['../datMats/', expName, '_meanArrayCA']); % nValence x nK x nObs (mean over reps)
load(['../datMats/', expName, '_sdArrayCAComp']); % nValence x nK (sd's over observers of mean over reps)
load(['../datMats/', expName, '_sdArrayCA']); % nValence x nK x nObs (sd's over reps) 
hum_means_CA = datArrayMean;
comp_hum_means_CA = datArrayMeanComp;
hum_sds_CA = datArraySD;
comp_hum_sds_CA = datArraySDComp;

ci95_CA = tinv(0.975, 2*n_reps-1)*hum_sds_CA/sqrt(n_reps); 
comp_ci95_CA = tinv(0.975, nObs-1)*hum_sds_CA/sqrt(nObs);

load(['../datMats/', expName, '_meanArrayPointsComp']); % nValence x nK (mean over observers and reps)
load(['../datMats/', expName, '_meanArrayPoints']); % nValence x nK x nObs (mean over reps)
load(['../datMats/', expName, '_sdArrayPointsComp']); % nValence x nK (sd's over observers of mean over reps)
load(['../datMats/', expName, '_sdArrayPoints']); % nValence x nK x nObs (sd's over reps) 
hum_means_points = datArrayMean;
comp_hum_means_points = datArrayMeanComp;
hum_sds_points = datArraySD;
comp_hum_sds_points = datArraySDComp;

ci95_points = tinv(0.975, 2*n_reps-1)*hum_sds_points/sqrt(n_reps); 
comp_ci95_points = tinv(0.975, nObs-1)*comp_hum_sds_points/sqrt(nObs);



% fixP model
load ../fix_prob_analyses/E3_fitFixPstheta.mat; % loads fitFixPstheta (best fit fixed p model)

% maxCurv model
load ../EV_curvature/maxCurvCA_E3.mat

% reward function
maxPointsGain  = 150; maxPointsLoss = 50; penPerDegree = -1;

%calulcate reward as a function of arc length
RGain = maxPointsGain + penPerDegree * (arcAngles);
Rrep1Gain(1, 1, :)  = RGain;
RrepGain = repmat(Rrep1Gain, 4, 1);
RLoss = maxPointsLoss + penPerDegree * (arcAngles);
Rrep1Loss(1, 1, :)  = RLoss;
RrepLoss = repmat(Rrep1Loss, 4, 1);

expPointsGain = RrepGain.*probCatch;
expPointsLoss = RrepLoss.*probCatch-100*(1-probCatch);

% get max exp points and assoc arc length
for i = 1:nK         
% note max ind is same for loss and gain so only have to do for one... 
         indMax1 = find(expPointsLoss(i, 1, :) == max(expPointsLoss(i, 1, :)));
         indMax(i) = indMax1(1) 
         maxExpLoss(i) = expPointsLoss(i, 1, indMax(i));
         maxExpGain(i) = expPointsGain(i, 1, indMax(i));
         maxAng(i) = mean(arcAngles(indMax(i)));  
end
if saveFlag
    maxAngName = [expName, '_MEVCA'];
    save([maxAngName, '.mat'], 'maxAng');
end

% efficiency calculations

% calculate efficiency for each observer and composite
maxExp = [maxExpLoss; maxExpGain];
%compEff = 100*comp_hum_means_points./maxExp;
maxExpRep = repmat(maxExp, [1 1 nObs]);
indivEff(2, :, :) = 100*hum_means_points(2, :, :)./maxExpRep(2, :, :);
indivEff(1, :, :) = 100*(100+hum_means_points(1, :, :))./(100+maxExpRep(1, :, :));

if saveFlag
    save('E3_indivEff', 'indivEff');
end
    
compEff = mean(indivEff, 3);
compEffsd = std(indivEff, 0, 3);
compEffse = compEffsd/sqrt(nObs);
compEffCI95 = tinv(0.975, nObs-1)*compEffse;
eff = cat(3, indivEff, compEff);


%%%% FIGURES %%%%


%mycol = ['b'; 'm'; 'c'; 'k'];
mycol = [.8 .8 .8; .7 .7 .7; .5 .5 .5; 0.3 0.3 0.3];
figure(1)
set(gca, 'fontsize', 20);
hold on;
for i = 1:nK
    %plot(arcAngles, squeeze(probCatchNoisy(i, :, :)), [mycol(i), 'o']);
    plot(arcAngles, squeeze(probCatchNoisy(i, :, :)), 'o',...
         'MarkerEdgeColor', mycol(i, :));
    h(i)=plot(arcAngles, squeeze(probCatch(i, :, :)), 'color', mycol(i, :), 'linewidth', 2);
end
hold off;
axis square;
xlabel('\theta_c - Catcher Angle (deg)')
ylabel('p_c_a_t_c_h(\theta_c, \kappa)');
legend(h, '\kappa = 25', '\kappa = 50', '\kappa = 75', '\kappa = 100');


figure(2)

 subplot(2, 1, 1)
 set(gca, 'fontsize', 24);
 hold on;
 axis([0 100 0 300])

% plot(arcAngles, RLoss, 'k--', 'linewidth', 2);
% plot([0 100], [-100 -100], 'k:', 'linewidth', 2)

% 
 subplot(2, 1, 2)
 set(gca, 'fontsize', 24);
 hold on;
% plot(arcAngles, RGain, 'k--', 'linewidth', 2)
% plot([0 100], [0 0], 'k:', 'linewidth', 2)
 axis([0 100 -300 0])
for i = 1:nK
    subplot(2, 1, 1)
%     h(i+2)=plot(arcAngles, squeeze(expPointsGain(i, :, :)), mycol(i), 'linewidth', 2);
%     plot([arcAngles(indMax(i)); arcAngles(indMax(i))],...
%                [-100, 150], [mycol(i),':'], 'linewidth', 3)
      h2(i)=plot(arcAngles, squeeze(expPointsGain(i, :, :)), 'color', mycol(i, :), 'linewidth', 2);
            plot([arcAngles(indMax(i)); arcAngles(indMax(i))],...
                [-300, 300], 'color', mycol(i, :), 'linewidth', 2)
      axis square
    subplot(2, 1, 2)
%     plot(arcAngles, squeeze(expPointsLoss(i, :, :)), mycol(i), 'linewidth', 2);
%     plot([arcAngles(indMax(i)); arcAngles(indMax(i))],...
%                [-100, 150], [mycol(i),':'], 'linewidth', 3)
     plot(arcAngles, squeeze(expPointsLoss(i, :, :)), 'color', mycol(i, :), 'linewidth', 2);
     plot([arcAngles(indMax(i)); arcAngles(indMax(i))],...
                [-300, 300], 'color', mycol(i, :), 'linewidth', 2)
     axis square       
end
hold off;
subplot(2, 1, 2)
xlabel('\theta_c - Catcher Angle (deg)')
ylabel('EV(\theta_c, \kappa)');
legend(h2, '\kappa = 25', '\kappa = 50', '\kappa = 75', '\kappa = 100');

%xlabel('Capture Angle (degs)')
%ylabel('Points');
%legend(h, 'Catch Reward (gain)', 'Catch Reward (loss)', 'EG25', 'EG50', 'EG75', 'EG100')


for i = 1:length(K)     
         
         figure(3)
         %%% LOSS
         mycol = [0.8 0.8 0.8; 0.0 0.0 0.0];
         %obsCol = ['b'; 'c'; 'm'; 'r'; 'y'];
         subplot(4, 2, (i-1)*2 +1)
         %subplot(2, 4, i);
         set(gca, 'fontsize', 16)
         %title(sprintf('K = %.0f', K(i)));
         hold on;
         plot(arcAngles, squeeze(expPointsLoss(i, 1, :)), 'color', mycol(1, :), 'linestyle', '-', 'linewidth', 3);
         
         plot(squeeze(hum_means_CA(1, i, :)), squeeze(hum_means_points(1, i, :)), 'ko', 'markerfacecolor', 'k')
%          herrorbar(squeeze(hum_means_CA(1, i, :)), squeeze(hum_means_points(1, i, :)),...
%                    squeeze(ci95_CA(1, i, :)));
%          errorbar(squeeze(hum_means_CA(1, i, :)), squeeze(hum_means_points(1, i, :)),...
%                    squeeze(ci95_points(1, i, :)), 'linestyle', 'none');
         plot([arcAngles(indMax(i)), arcAngles(indMax(i))],...
               [-300, 300], 'color', mycol(1, :), 'linestyle', '-', 'linewidth', 3)
         plot([comp_hum_means_CA(1, i), comp_hum_means_CA(1, i)],...
               [-300, 300], 'k:', 'linewidth', 3) 

         
         plot(squeeze(hum_means_CA(1, i, :)), squeeze(hum_means_points(1, i, :)), 'ko', 'markerfacecolor', 'k')
         plot(comp_hum_means_CA(1, i), comp_hum_means_points(1, i), 'ko', 'markerfacecolor', 'y', 'markersize', 12)
         
         axis([0 100 -200 0])
         axis square
         %hold off;
         
        %%%GAIN
         %obsCol = ['b'; 'c'; 'm'; 'r'; 'y'];
         subplot(4, 2, i*2);
         set(gca, 'fontsize', 18)
         %title(sprintf('K = %.0f', K(i)));
         hold on;
         plot(arcAngles, squeeze(expPointsGain(i, 1, :)), 'color', mycol(2, :), 'linestyle', '-', 'linewidth', 2);
         %plot(arcAngles(indMax), maxExp(i, j), 'r*', 'markerfacecolor', 'r')
         %for k = 1:5
         %plot([squeeze(hum_means_CA(j, i, k)), squeeze(hum_means_CA(j, i, k))],...
         %      [0 6], [obsCol(k), ':'], 'linewidth', 1);
         %plot(squeeze(hum_means_CA(j, i, k)), squeeze(hum_means_points(j, i, k)), [obsCol(k), 'o'], 'markerfacecolor', obsCol(k))  
         %  end
         plot(squeeze(hum_means_CA(2, i, :)), squeeze(hum_means_points(2, i, :)), 'ko', 'markerfacecolor', 'k')
%          herrorbar(squeeze(hum_means_CA(2, i, :)), squeeze(hum_means_points(2, i, :)),...
%                    squeeze(ci95_CA(2, i, :)));
%          errorbar(squeeze(hum_means_CA(2, i, :)), squeeze(hum_means_points(2, i, :)),...
%                    squeeze(ci95_points(2, i, :)), 'linestyle', 'none');
         plot([arcAngles(indMax(i)), arcAngles(indMax(i))],...
               [-300, 300], 'color', mycol(2, :), 'linestyle', '-', 'linewidth', 2)
         plot([comp_hum_means_CA(2, i), comp_hum_means_CA(2, i)],...
               [-300, 300], 'k:', 'linewidth', 3) 
         
         plot(squeeze(hum_means_CA(2, i, :)), squeeze(hum_means_points(2, i, :)), 'ko', 'markerfacecolor', 'k')
         plot(comp_hum_means_CA(2, i), comp_hum_means_points(2, i), 'bo', 'markerfacecolor', 'y',  'markersize', 12)
         
         axis([0 100 0 200]);
         axis square
end
subplot(4, 2, 7)
ylabel('Points')
xlabel('\theta_c - Catcher Angle (deg)')



mycol = [0.7 0.7 0.7; 0.3 0.3 0.3];
figure(4)
fitFixPsthet_mean = mean(fitFixPstheta, 3); % mean over obs [nVals x nK]
humSECA = comp_hum_sds_CA/sqrt(nObs);
set(gca, 'fontsize', 18)
hold on;
plot(K, maxAng, 'r','linewidth', 2)
h1 = plot(K, maxAng, 'k^','markersize', 12, 'markerfacecolor', 'r');
plot(K, fitFixPsthet_mean(1, :), 'm','linewidth', 2)
h2 = plot(K, fitFixPsthet_mean(1, :), 'k<', 'markersize', 12, 'markerfacecolor', 'm');
plot(K, maxCurvCA, 'c','linewidth', 2)
h3 = plot(K, maxCurvCA, 'k>', 'markersize', 12, 'markerfacecolor', 'c');

%plot(K, maxAng(:, i), mycol(i, 1))
errorbar(K, comp_hum_means_CA(1, :),  humSECA(1, :), 'color', mycol(1,:), 'linewidth', 1, 'linestyle', ':');
h4 = plot(K, comp_hum_means_CA(1, :),  'ko',  'markersize', 12, 'markerfacecolor', mycol(1,:));
errorbar(K, comp_hum_means_CA(2, :),  humSECA(2, :), 'color', mycol(2,:), 'linewidth', 1, 'linestyle', ':');
h5 = plot(K, comp_hum_means_CA(2, :),  'ko',  'markersize', 12, 'markerfacecolor', mycol(2,:));
legend([h1 h2 h3 h4 h5], 'MEV', 'FixP', 'maxCrv', 'Loss', 'Gain')
%xlabel('K')
%ylabel('Catch Angle (degrees)')
xlabel('Reliability (K)')
ylabel('\theta_c - Catcher Angle (deg)')
hold off;
axis([20 105 30 55]);

%axis([20 105 30 55])
set(gca, 'xtick', [25 50 75 100])

% mycol = ['ro';'gs';'bv'; 'y^']
% figure(5)
% humSEpoints = comp_hum_sds_points/sqrt(nObs);
% set(gca, 'fontsize', 16)
% hold on;
% %h1 = plot(K, maxAng, 'b')
% %plot(K, maxAng(:, i), mycol(i, 1))
% h2 = plot(K, comp_hum_means_points(1, :),  'r', 'markersize', 10, 'markerfacecolor', 'r');
% h3 = errorbar(K, comp_hum_means_points(1, :),  humSEpoints(1, :), 'r', 'linestyle', 'none');
% h4 = plot(K, comp_hum_means_points(2, :),  'g', 'markersize', 10, 'markerfacecolor', 'g');
% h3 = errorbar(K, comp_hum_means_points(2, :),  humSEpoints(2, :), 'g', 'linestyle', 'none');
% %legend([h1 h2 h4], 'Optimal', 'Loss', 'Gain')
% xlabel('K')
% ylabel('Catch Angle (degrees)')
% hold off;
% %axis([0 120 30 60])
         
figure(6)
for i = 1:length(K)
        subplot(4, 1, i);
        hold on;
        set(gca, 'fontsize', 32)
        bar(squeeze(eff(1, i, 1:nObs)), 'r');
        bar(nObs+1, squeeze(eff(2, i, nObs+1)), 'm');
        set(gca, 'xtick', [], 'ytick', [0 100]);
        %title(sprintf('K = %.0f, W = %.3f', K(i), occ_width));
        errorbar(nObs+1, eff(1, i, nObs+1), compEffCI95(1, i), 'k') 
        axis([0 52 0 150])
        plot([0 55], [100 100], 'k--')
        hold off
end
% subplot(4, 1, 4)
% xlabel('Participant')
% ylabel('Efficiency (%)')
hold off

figure(7)
for i = 1:length(K)
        subplot(4, 1, i);
        hold on;
        set(gca, 'fontsize', 32)
        bar(squeeze(eff(2, i, 1:nObs)), 'g');
        bar(nObs, squeeze(eff(2, i, nObs+1)), 'm');
        set(gca, 'xtick', [], 'ytick', [0 100]);
        %title(sprintf('K = %.0f, W = %.3f', K(i), occ_width));
        errorbar(nObs+1, eff(2, i, nObs+1), compEffCI95(2, i), 'k'); 
        axis([0 52 0 150])
        plot([0 55], [100 100], 'k--')
        hold off
end
% subplot(4, 1, 4)
% xlabel('Participant')
% ylabel('Efficiency (%)')
hold off


figure(8)
set(gca, 'fontsize', 24)
hold on;
mycol = [0.7 0.7 0.7;  0.5 0.5 0.5; 0.3 0.3 .3; .1 .1 .1];
errbars=[compEffCI95(1, 1:nK); compEffCI95(2, 1:nK)]
effs = [squeeze(eff(1, 1:nK, nObs+1)); squeeze(eff(2, 1:nK, nObs+1))];
h = bar(effs,'grouped');hold on;
ngroups = nVal; % gain/loss
nbars = nK;
% Calculating the width for each bar group
groupwidth = min(0.8, nbars/(nbars + 1.5));

for i = 1:nbars
    set(h(i), 'facecolor', mycol(i, :));
    x = (1:ngroups) - groupwidth/2 + (2*i-1) * groupwidth / (2*nbars);
    errorbar(x, effs(:,i), errbars(:,i), 'linestyle', 'none', 'color', [0 0 0]);
end
plot([.5 2.5], [100 100], 'r:')
hold off
ylabel('Efficiency (%)')
set(gca, 'fontsize', 24, 'xtick', [1 2], 'xticklabel', ['Loss'; 'Gain'])
legend('\kappa = 25', '\kappa = 50', '\kappa =75', '\kappa =100')


