function [toOcc, underOcc, absAngOut, absAngIn] = MC_mot_extrap2(nSims, bias, K, ringRad, speed, fRate, plotFlag)

% function to simulate paths up to occluder and then under occluder for diff, vM distribs and
% 
% nSims = [noof upto occluder simulations, noof under occluder sims]
% bias =  bias on von Mises distribution (0 implies dot movement centred on 
%         current direction at each time step
% K    =  von Mises concentration parameter
% ringRad = inner and outer radii of occluder ring (m)
% speed = dot speed (m/s)
% plotFlag = plotting flag
% 
% paths = output cell array containing 3xnSteps(i) (x, y, relDir) locations at each
%         time step
% absAngOut = angular position on outer radius relative to x axis (degrees)
% absAngIn = angular position on inner radius relative to x axis (degrees)

DEG2RAD = pi/180;
RAD2DEG = 180/pi;

%speed = 0.015; % m/s
%fRate = 60; % frm/s

count1 = 0;

NtoOcc = nSims(1);
NunderOcc = nSims(2);

%samps = rand_von_mises(1000000, 1, bias, K, -pi, pi);

for i = 1:NtoOcc
    fprintf('k = %d, i = %d of %d\n', K, i, NtoOcc);
    
    pathDone1 = 0;
    ind = 1;
    toOcc{i} = zeros(3, 1); %(x, y, rel dir)
    toOcc{i}(:, 1) = [0; 0; 0];
   % fixed displacement per frame
    disp = speed/fRate;
    
    %%% UPTO OCCLUDER
    while ~pathDone1
       xTemp = toOcc{i}(1, ind);
       yTemp = toOcc{i}(2, ind);
       dirTemp = toOcc{i}(3, ind);

       % current distance from origin
       coordsRad =  sqrt(xTemp*xTemp+yTemp*yTemp);

       % sample new change in direction (should be between -pi and pi)
       dirChange = rand_von_mises(1, 1, bias, K, -pi, pi);%samps(ind);

       % new direction
       newDir = dirTemp+RAD2DEG*dirChange;
       % convert to [-180, 180] range
       newDir = ang180(newDir);

       % update dot location
       toOcc{i}(1, ind+1) = xTemp + disp*cos(DEG2RAD*newDir);
       toOcc{i}(2, ind+1) = yTemp + disp*sin(DEG2RAD*newDir);
       toOcc{i}(3, ind+1) = newDir;
       
            
       if coordsRad >= ringRad(1)
          pathDone1 = 1;
       end
          
       ind = ind+1;
    end; % while (not pathDone1)
    absAngIn(i) = ang180(RAD2DEG*atan2(toOcc{i}(2, ind), toOcc{i}(1, ind)));
    %%% UNDER OCCLUDER
    for j = 1:NunderOcc 
          if mod(j, 500) == 0
             fprintf('%d\n', j);
          end
        pathDone2 = 0;
        %samps = rand_von_mises(10000, 1, bias, K, -pi, pi);
        underOcc{i, j} = zeros(3, 1); %(x, y, rel dir)
        underOcc{i, j}(:, 1) = toOcc{i}(:, ind);    
        ind2 = 1;

        while ~pathDone2
           xTemp = underOcc{i, j}(1, ind2);
           yTemp = underOcc{i, j}(2, ind2);
           dirTemp = underOcc{i, j}(3, ind2);

           % current distance from origin
           coordsRad =  sqrt(xTemp*xTemp+yTemp*yTemp);

           % sample new change in direction (should be between -pi and pi)
           dirChange = rand_von_mises(1, 1, bias, K, -pi, pi);%samps(ind+ind2);

           % new direction
           newDir = dirTemp+RAD2DEG*dirChange;
           % convert to [-180, 180] range
           newDir = ang180(newDir);

           % update dot location
           underOcc{i, j}(1, ind2+1) = xTemp + disp*cos(DEG2RAD*newDir);
           underOcc{i, j}(2, ind2+1) = yTemp + disp*sin(DEG2RAD*newDir);
           underOcc{i, j}(3, ind2+1) = newDir;


           if coordsRad >= ringRad(2)
              pathDone2 = 1;
           end

           ind2 = ind2+1;
        end; % while (not pathDone2)
        absAngOut(i, j) = ang180(RAD2DEG*atan2(underOcc{i, j}(2, ind2), underOcc{i, j}(1, ind2)));

    end; % for j = 1:NunderOcc
end; % for i = 1:NtoOcc

xRingOut = linspace(-ringRad(2), ringRad(2));
yRingOut = sqrt(ringRad(2)^2-xRingOut.^2);
xRingIn = linspace(-ringRad(1), ringRad(1));
yRingIn = sqrt(ringRad(1)^2-xRingIn.^2);
if plotFlag
    close all;
    figure(1);
    hold on;
    plot(xRingIn, yRingIn, 'b');
    plot(xRingIn, -yRingIn, 'b');
    plot(xRingOut, yRingOut, 'b');    
    plot(xRingOut, -yRingOut, 'b');    
    for i = 1:NtoOcc
       plot(toOcc{i}(1, :), toOcc{i}(2, :), 'r')
       for j = 1:NunderOcc
           plot(underOcc{i, j}(1, :), underOcc{i, j}(2, :), 'g')
       end
    end
        
    
    axis square
    axis off
    axis tight
end

hold off;
