function theta = rand_von_mises(nrows, ncols, bias, K, min, max)

% theta = rand_von_mises(nrows, ncols, bias, K, min, max)
%
% returns an nrows x ncols array of random values taken from a von mises 
% distribution specified by bias parameter bias and concentration K (>=0). The 
% range of the distribution is set by min and max.
% Adapted from code written by Pascal Mamassian

% range of distribution
range = max-min;
rel_range = range/(2*pi);

theta = zeros(nrows, ncols);

% if K = 0 generate uniform random angle
if (K <= 1e-6)
	theta = -((range)/2)+rand(nrows, ncols)*(range);
	return;
end

aa = 1+sqrt(1+4*K^2);
bb = (aa - sqrt(2*aa))/(2*K);
rr = (1+bb^2)/(2*bb);

for i = 1:nrows
	for j = 1:ncols

		test = 1;
		while (test)
			u1 = rand(1, 1);
			zz = cos(pi*u1);
			ff = (1+rr*zz)/(rr+zz);
			cc = K*(rr-ff);
			
			u2 = rand(1, 1);
			test = (u2 >= cc*(2-cc)) & (u2 > cc*exp(1-cc));
		end
		
		u3 = rand(1, 1);
		if (u3 > 0.5)
			theta(i, j) = bias+rel_range*acos(ff);
		else
			theta(i, j) = bias-rel_range*acos(ff);
		end
		
		while (theta(i, j) < min)
			theta(i, j) = theta(i, j)+range;
		end
		while (theta(i, j) > max)
			theta(i, j) = theta(i, j)-range;
		end
	
	end
end
