function  EV = expValFunc(expName, fitParams, funcForm, plotFlag)
%Function to plot expected value curves based on fitted p(Catch) function
%using fitProb to recover best fitting params

if strcmp(expName, 'E1')
    nK = 3;
    arcAngles = 1:1:100;
    % load data (in form kvals x 1 x catchSizes)
    load(['E1E2_probCatchHumNoise_newSD_FR60_consistent']);
    pointsParams = [300 -1 0];
elseif strcmp(expName, 'E2')
    nK = 3;
    arcAngles = 1:1:100;
    % load data (in form kvals x 1 x catchSizes)
    load(['E1E2_probCatchHumNoise_newSD_FR60_consistent']);
    pointsParams = [150 -1 0];
elseif strcmp(expName, 'E3')
    nK = 4;
    arcAngles = 1:1:100;
    % load data (in form kvals x 1 x catchSizes)
    load([expName, '_probCatchHumNoise_newSD_FR60_consistent']);
    pointsParams = [150 -1 0];
elseif strcmp(expName, 'WGMC')
    nK = 4
    arcAngles = 1:1:120;
    % load data (in form kvals x 1 x catchSizes)
    load([expName, '_probCatchHumNoise_100_1000']);
    % just get 2.5cm occluder data
    probCatch = probCatch(:, 2, :)
    pointsParams = [6 -0.05 0];
end


maxCatch = pointsParams(1);
penPerDeg = pointsParams(2);
miss = pointsParams(3);
pointsCatch = maxCatch + penPerDeg * arcAngles;

if plotFlag
    figure;
    hold on;
    myCol = ['r'; 'g'; 'b'; 'm'];
end
for i = 1:nK
    pCatchFit(i, :) = probFunc(fitParams(i, :), funcForm, arcAngles);
    EVFit(i, :) = pCatchFit(i, :).*pointsCatch + (1-pCatchFit(i, :))*miss
    EV(i, :) = probCatch(i, :).*pointsCatch + (1-probCatch(i, :))*miss
    if plotFlag
        plot(arcAngles, EVFit(i, :), [myCol(i)])
        plot(arcAngles, EV(i, :), [myCol(i) 'o'])
        
    end
end
hold off;
