function fitParams = fitProb(startParams, funcForm, expName, plotFlag, saveFlag)

% function to fit logistic form to prob(catch) data across experiments

if strcmp(expName, 'E1E2')
    nK = 3;
    arcAngles = 1:1:100;
    % load data (in form kvals x 1 x catchSizes)
    load([expName, '_probCatchHumNoise_newSD_FR60_consistent']);
elseif strcmp(expName, 'E3')
    nK = 4;
    arcAngles = 1:1:100;
    % load data (in form kvals x 1 x catchSizes)
    load([expName, '_probCatchHumNoise_newSD_FR60_consistent']);
elseif strcmp(expName, 'WGMC')
    nK = 4
    arcAngles = 1:1:120;
    % load data (in form kvals x 1 x catchSizes)
    load([expName, '_probCatchHumNoise_100_1000']);
    % just get 2.5cm occluder data
    probCatch = probCatch(:, 2, :)
end

% squeeze to be kVals x catchSizes
probCatch = squeeze(probCatch);

if plotFlag
    figure;
    hold on;
    mycol = ['r'; 'g'; 'b'; 'm']
end

options = optimset('display', 'iter')
for i = 1:nK
    fitParams(i, :) = fminsearch('probFuncErr', startParams, options, funcForm, arcAngles, probCatch(i, :));
    if plotFlag
        h(2*i-1)=plot(arcAngles, probCatch(i, :), [mycol(i), 'o']);
        h(2*i)=plot(arcAngles, probFunc(fitParams(i, :), funcForm, arcAngles), mycol(i));
    end
end

if saveFlag    
    saveName = ['pCatchParams', expName, '.mat']
    save(saveName, 'fitParams');
end


